@@ -29,6 +29,10 @@ done
 base_rev="$(git rev-parse --short --verify "refs/top-bases/$name" 2>/dev/null)" ||
 	die "not a TopGit-controlled branch"
 
+if ! git send-email --help >/dev/null 2>&1; then
+	die "git send-email command not available"
+fi
+
 if [ -n "$in_reply_to" ]; then
 	send_email_args="$send_email_args --in-reply-to=$in_reply_to"
 fi
@@ -55,3 +59,5 @@ people=
 eval git send-email $send_email_args "$people" "$patchfile"
 
 rm "$patchfile"
+
+# vim:noet
